#
# Fedora spec file for php-erusev-parsedown
#
# Copyright (c) 2017 Shawn Iwinski <shawn@iwin.ski>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     erusev
%global github_name      parsedown
%global github_version   1.6.3
%global github_commit    728952b90a333b5c6f77f06ea9422b94b585878d

%global composer_vendor  erusev
%global composer_project parsedown

# "php": ">=5.3.0"
%global php_min_ver 5.3.0

# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-%{composer_vendor}-%{composer_project}
Version:       %{github_version}
Release:       1%{?github_release}%{?dist}
Summary:       Markdown parser in PHP

Group:         Development/Libraries
License:       MIT
URL:           http://parsedown.org

# GitHub export does not include tests.
# Run php-erusev-parsedown-get-source.sh to create full source.
Source0:       %{name}-%{github_version}-%{github_commit}.tar.gz
Source1:       %{name}-get-source.sh

BuildArch:     noarch
# Tests
%if %{with_tests}
## composer.json
BuildRequires: php(language) >= %{php_min_ver}
BuildRequires: php-composer(phpunit/phpunit)
## phpcompatinfo (computed from version 1.6.3)
BuildRequires: php-mbstring
BuildRequires: php-pcre
BuildRequires: php-spl
## Autoloader
BuildRequires: php-composer(fedora/autoloader)
%endif

# composer.json
Requires:      php(language) >= %{php_min_ver}
# phpcompatinfo (computed from version 1.6.3)
Requires:      php-mbstring
Requires:      php-pcre
Requires:      php-spl
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
%{summary}.

Autoloader: %{phpdir}/%{composer_vendor}/%{composer_project}/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Create autoloader
cat <<'AUTOLOAD' | tee autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 */
require_once '%{phpdir}/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addClassMap(array(
    'parsedown' => '/Parsedown.php',
), __DIR__);
AUTOLOAD


%install
mkdir -p %{buildroot}%{phpdir}/%{composer_vendor}/%{composer_project}
cp -rp Parsedown.php autoload.php \
    %{buildroot}%{phpdir}/%{composer_vendor}/%{composer_project}/


%check
%if %{with_tests}
: Upstream tests
RETURN_CODE=0
PHPUNIT=$(which phpunit)
for PHP_EXEC in php %{?rhel:php54 php55} php56 php70 php71 php72; do
    if [ -z "$PHP_EXEC" ] || which $PHP_EXEC; then
        $PHP_EXEC $PHPUNIT --verbose \
            --bootstrap %{buildroot}%{phpdir}/%{composer_vendor}/%{composer_project}/autoload.php \
            || RETURN_CODE=1
    fi
done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE.txt
%doc *.md
%doc composer.json
%dir %{phpdir}/%{composer_vendor}
     %{phpdir}/%{composer_vendor}/%{composer_project}


%changelog
* Sat Jul 08 2017 Shawn Iwinski <shawn@iwin.ski> - 1.6.3-1
- Update to 1.6.3 (RHBZ #1468067)
- Add "get source" script because upstream attributes removed tests from snapshot

* Sun Jun 11 2017 Shawn Iwinski <shawn@iwin.ski> - 1.6.2-2
- Fix directory ownership

* Tue May 30 2017 Shawn Iwinski <shawn@iwin.ski> - 1.6.2-1
- Initial package
